## 可转债票面利率

接口：cb_rate

描述：获取可转债票面利率

限量：单次最大2000，总量不限制

权限：用户需要至少5000积分才可以调取，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 转债代码，支持多值输入 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 转债代码 |
| rate_freq | int | N | 付息频率(次/年) |
| rate_start_date | str | N | 付息开始日期 |
| rate_end_date | str | N | 付息结束日期 |
| coupon_rate | float | N | 票面利率(%) |

接口示例

```python
pro = ts.pro_api(your token)
#获取可转债基础信息列表
df = pro.cb_rate(ts_code='123046.SZ,127064.SZ',fields="ts_code,rate_freq,rate_start_date,rate_end_date,coupon_rate")
```

数据示例

```python
ts_code  rate_freq rate_start_date rate_end_date coupon_rate
0   123046.SZ          1        20200319      20210318    0.500000
```